part of navigine_sdk;

class NavigationThread {
  NavigationThread._();

  stopNavigation() async {
    await _channel.invokeMethod("stopNavigation");
  }

  Future<void> addTarget(LocationPoint point) async {
    await _channel.invokeMethod(
      "addTarget",
      {"locationPoint": point.toMap()},
    );
  }

  Future<void> cancelTarget() async {
    await _channel.invokeMethod("cancelTarget");
  }

  Future<RoutePath> makeRoute(
    LocationPoint point1,
    LocationPoint point2,
  ) async {
    return RoutePath.fromMap(
      await _channel.invokeMethod(
        "makeRoute",
        {
          "locationPoint1": point1.toMap(),
          "locationPoint2": point2.toMap(),
        },
      ),
    );
  }

  _handleNativeCall(MethodCall call) async {
    switch (call.method) {
      case "deviceInfo#onUpdate":
        _deviceInfoController?.add(DeviceInfo.fromMap(call.arguments));
        break;
      default:
    }
  }

  StreamController<DeviceInfo>? _deviceInfoController;

  Stream<DeviceInfo> getDeviceInfoListener() {
    _deviceInfoController = StreamController<DeviceInfo>();
    _deviceInfoController!.onCancel = () async {
      await _channel.invokeMethod("stopNavigation");
      _deviceInfoController!.close();
      _deviceInfoController = null;
    };
    return _deviceInfoController!.stream;
  }

  Future<DeviceInfo> getDeviceInfo() async {
    return DeviceInfo.fromMap(await _channel.invokeMethod("getDeviceInfo"));
  }
}

enum NavigationMode {
  MODE_IDLE,
  MODE_SCAN,
  MODE_NORMAL,
  MODE_ECONOMIC,
}
